==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/core/iactorcollection.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iactorcollection.h"


#include "iactor.h"

//
//  Templates
//
#include "iarraytemplate.h"


iActorCollection* iActorCollection::New()
{
	return new iActorCollection();
}

	
iActorCollection::iActorCollection()
{
}


iActorCollection::~iActorCollection()
{
	int i;
	for(i=0; i<mActors.Size(); i++) mActors[i]->UnRegister(this);
}


void iActorCollection::SetVisibility(int s)
{
	int i;
	for(i=0; i<mActors.Size(); i++) mActors[i]->SetVisibility(s);
}


void iActorCollection::AddActor(iActor *a)
{
	if(a != 0)
	{
		mActors.AddUnique(a);
		a->Register(this);
	}
}


void iActorCollection::RemoveActor(iActor *a)
{
	if(a != 0)
	{
		iActor *tmp = mActors.Remove(a);
		if(tmp != 0) tmp->UnRegister(this);
	}
}

==> ifrit_3.2.0.orig.tar.gz: ifrit-3.2.0/core/iactorcollection.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iactorcollection.h"


#include "iactor.h"

//
//  Templates
//
#include "iarraytemplate.h"


iActorCollection* iActorCollection::New()
{
	return new iActorCollection();
}

	
iActorCollection::iActorCollection()
{
}


iActorCollection::~iActorCollection()
{
	int i;
	for(i=0; i<mActors.Size(); i++) mActors[i]->UnRegister(this);
}


void iActorCollection::SetVisibility(int s)
{
	int i;
	for(i=0; i<mActors.Size(); i++) mActors[i]->SetVisibility(s);
}


void iActorCollection::AddActor(iActor *a)
{
	if(a != 0)
	{
		mActors.AddUnique(a);
		a->Register(this);
	}
}


void iActorCollection::RemoveActor(iActor *a)
{
	if(a != 0)
	{
		if(mActors.Remove(a)) a->UnRegister(this);
	}
}
